@@ -2,15 +2,15 @@ from django import forms
 from django.utils.translation import gettext_lazy as _
 
 from userena.contrib.umessages.fields import CommaSeparatedUserField
-from userena.contrib.umessages.models import Message, MessageRecipient
-
-import datetime
+from userena.contrib.umessages.models import Message
 
 
 class ComposeForm(forms.Form):
     to = CommaSeparatedUserField(label=_("To"))
     body = forms.CharField(
-        label=_("Message"), widget=forms.Textarea({"class": "message"}), required=True
+        label=_("Message"),
+        widget=forms.Textarea({"class": "message"}),
+        required=True,
     )
 
     def save(self, sender):
