@@ -1,7 +1,7 @@
 from functools import WRAPPER_ASSIGNMENTS, wraps
 
-from django.http import HttpResponsePermanentRedirect
 from django.conf import settings
+from django.http import HttpResponsePermanentRedirect
 
 from userena import settings as userena_settings
 
@@ -27,7 +27,9 @@ def secure_required(view_func):
                 "USERENA_USE_HTTPS",
                 userena_settings.DEFAULT_USERENA_USE_HTTPS,
             ):
-                request_url = request.build_absolute_uri(request.get_full_path())
+                request_url = request.build_absolute_uri(
+                    request.get_full_path()
+                )
                 secure_url = request_url.replace("http://", "https://")
                 return HttpResponsePermanentRedirect(secure_url)
         return view_func(request, *args, **kwargs)
